package VMOMI::ActionParameter;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
